==> elo_indexserver_client-0.1.2.tar.gz: elo_indexserver_client-0.1.2/eloclient/models/b_request_ix_service_port_if_export_workflow.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.workflow_export_options import WorkflowExportOptions


T = TypeVar("T", bound="BRequestIXServicePortIFExportWorkflow")


@_attrs_define
class BRequestIXServicePortIFExportWorkflow:
    """
    Attributes:
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface function, except the
             login, requires a <code>ClientInfo</code> object as parameter with a valid session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        wf_export_options (Union[Unset, WorkflowExportOptions]): Structure for the options for the workflow-export.
            <p>
             Copyright: Copyright (c) 2009
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
    """

    ci: Union[Unset, "ClientInfo"] = UNSET
    wf_export_options: Union[Unset, "WorkflowExportOptions"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        wf_export_options: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf_export_options, Unset):
            wf_export_options = self.wf_export_options.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ci is not UNSET:
            field_dict["ci"] = ci
        if wf_export_options is not UNSET:
            field_dict["wfExportOptions"] = wf_export_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.workflow_export_options import WorkflowExportOptions

        d = src_dict.copy()
        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        _wf_export_options = d.pop("wfExportOptions", UNSET)
        wf_export_options: Union[Unset, WorkflowExportOptions]
        if isinstance(_wf_export_options, Unset):
            wf_export_options = UNSET
        else:
            wf_export_options = WorkflowExportOptions.from_dict(_wf_export_options)

        b_request_ix_service_port_if_export_workflow = cls(
            ci=ci,
            wf_export_options=wf_export_options,
        )

        b_request_ix_service_port_if_export_workflow.additional_properties = d
        return b_request_ix_service_port_if_export_workflow

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> elo_indexserver_client-0.1.30.tar.gz: elo_indexserver_client-0.1.30/eloclient/models/b_request_ix_service_port_if_export_workflow.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.workflow_export_options import WorkflowExportOptions


T = TypeVar("T", bound="BRequestIXServicePortIFExportWorkflow")


@_attrs_define
class BRequestIXServicePortIFExportWorkflow:
    """
    Attributes:
        wf_export_options (Union[Unset, WorkflowExportOptions]): Structure for the options for the workflow-export.
            <p>
             Copyright: Copyright (c) 2009
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface
             function, except the login, requires a <code>ClientInfo</code> object as parameter with a valid
             session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
    """

    wf_export_options: Union[Unset, "WorkflowExportOptions"] = UNSET
    ci: Union[Unset, "ClientInfo"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        wf_export_options: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf_export_options, Unset):
            wf_export_options = self.wf_export_options.to_dict()

        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if wf_export_options is not UNSET:
            field_dict["wfExportOptions"] = wf_export_options
        if ci is not UNSET:
            field_dict["ci"] = ci

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.workflow_export_options import WorkflowExportOptions

        d = src_dict.copy()
        _wf_export_options = d.pop("wfExportOptions", UNSET)
        wf_export_options: Union[Unset, WorkflowExportOptions]
        if isinstance(_wf_export_options, Unset):
            wf_export_options = UNSET
        else:
            wf_export_options = WorkflowExportOptions.from_dict(_wf_export_options)

        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        b_request_ix_service_port_if_export_workflow = cls(
            wf_export_options=wf_export_options,
            ci=ci,
        )

        b_request_ix_service_port_if_export_workflow.additional_properties = d
        return b_request_ix_service_port_if_export_workflow

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
